@@ -24,7 +24,8 @@ class RainPublisher(Publisher):
             'hostname': gethostname(),
             'name': self.sensor.name,
             'location':self.location,
-            'kind': self.sensor.kind
+            'kind': self.sensor.kind,
+            'frequency': self.freq,
         }
         logger.info(f"emitting data as '{self.sensor.name}' every {freq}s")
 
